summaryrefslogtreecommitdiffstats
path: root/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/components/debugger/dbgp/qbytearrayfifo.cpp')
-rw-r--r--quanta/components/debugger/dbgp/qbytearrayfifo.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
index 6a52ac39..578fedb9 100644
--- a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
+++ b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
@@ -38,7 +38,7 @@ TQString TQByteArrayFifo::retrieve( )
for(size_t cnt = 0; cnt < m_size; cnt++)
m_array[cnt] = m_array[cnt + size];
// Resize array, needed for tqfind() to work
m_array.resize(m_size);
return str;
@@ -60,13 +60,13 @@ bool TQByteArrayFifo::append(const char * chars, size_t size )
return true;
}
-long TQByteArrayFifo::tqfind( char character )
+long TQByteArrayFifo::find( char character )
{
// If size is 0, tqfind() outputs a warning for some reason
if(m_size == 0)
return -1;
- return m_array.tqfind(character);
+ return m_array.find(character);
}
TQString TQByteArrayFifo::base64Encoded()
@@ -38,7 +38,7 @@ TQString TQByteArrayFifo::retrieve( )
for(size_t cnt = 0; cnt < m_size; cnt++)
m_array[cnt] = m_array[cnt + size];
- // Resize array, needed for tqfind() to work
+ // Resize array, needed for find() to work
m_array.resize(m_size);
return str;
@@ -60,13 +60,13 @@ bool TQByteArrayFifo::append(const char * chars, size_t size )
{
- // If size is 0, tqfind() outputs a warning for some reason
+ // If size is 0, find() outputs a warning for some reason
if(m_size == 0)
return -1;